==> haskell-semigroups-0.18.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.2
id: semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
key: semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Semigroup.Generic
abi: ae79f8144ae4534424ca0d55d1497559
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/semigroups-0.18.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/semigroups-0.18.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/semigroups-0.18.2
hs-libraries: HSsemigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semigroups-0.18.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroups
version: 0.18.3
id: semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
key: semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroups/
synopsis: Anything that associates
description:
    In mathematics, a semigroup is an algebraic structure consisting of a set together with an associative binary operation. A semigroup generalizes a monoid in that there might not exist an identity element. It also (originally) generalized a group (a monoid with all inverses) to a type where every element did not have to have an inverse, thus the name semigroup.
category: Algebra, Data, Data Structures, Math
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Semigroup.Generic
abi: b145d9096db68c1903c748edffc03f10
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/semigroups-0.18.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/semigroups-0.18.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/semigroups-0.18.3
hs-libraries: HSsemigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
haddock-html: /usr/share/doc/haskell-semigroups/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
